@@ -29,31 +29,30 @@ namespace Akonadi {
  */
 class ItemModifyJobPrivate : public JobPrivate
 {
-  public:
-    enum Operation
-    {
-      RemoteId,
-      RemoteRevision,
-      Gid,
-      Dirty
+public:
+    enum Operation {
+        RemoteId,
+        RemoteRevision,
+        Gid,
+        Dirty
     };
 
-    ItemModifyJobPrivate( ItemModifyJob *parent );
+    ItemModifyJobPrivate(ItemModifyJob *parent);
 
     void setClean();
     QByteArray nextPartHeader();
 
     void conflictResolved();
-    void conflictResolveError( const QString& );
+    void conflictResolveError(const QString &);
 
-    void doUpdateItemRevision( Entity::Id, int oldRevision, int newRevision );
+    void doUpdateItemRevision(Entity::Id, int oldRevision, int newRevision);
 
     QString jobDebuggingString() const /*Q_DECL_OVERRIDE*/;
     QByteArray fullCommand() const;
 
     void setSilent( bool silent );
 
-    Q_DECLARE_PUBLIC( ItemModifyJob )
+    Q_DECLARE_PUBLIC(ItemModifyJob)
 
     QSet<int> mOperations;
     QByteArray mTag;
