@@ -25,10 +25,14 @@
 #include "exception.h"
 #include "itemserializer_p.h"
 #include "itemserializerplugin.h"
+#include "servermanager.h"
+#include <akonadi/private/xdgbasedirs_p.h>
 
 #include <QtCore/QDateTime>
 #include <QtCore/QFile>
 #include <QtCore/QVarLengthArray>
+#include <QtCore/QFileInfo>
+#include <QtCore/QDir>
 
 #include <kdebug.h>
 #include <klocalizedstring.h>
@@ -126,6 +130,17 @@ void ProtocolHelper::parseAncestors( const QByteArray &data, Entity *entity, int
   }
 }
 
+static Collection::ListPreference parsePreference( const QByteArray &value )
+{
+  if ( value == "TRUE" ) {
+    return Collection::ListEnabled;
+  }
+  if ( value == "FALSE" ) {
+    return Collection::ListDisabled;
+  }
+  return Collection::ListDefault;
+}
+
 int ProtocolHelper::parseCollection(const QByteArray & data, Collection & collection, int start)
 {
   int pos = start;
@@ -192,6 +207,16 @@ int ProtocolHelper::parseCollection(const QByteArray & data, Collection & collec
       collection.setCachePolicy( policy );
     } else if ( key == "ANCESTORS" ) {
       parseAncestors( value, &collection );
+    } else if ( key == "ENABLED" ) {
+      collection.setEnabled( value == "TRUE" );
+    } else if ( key == "DISPLAY" ) {
+      collection.setLocalListPreference( Collection::ListDisplay, parsePreference( value ) );
+    } else if ( key == "SYNC" ) {
+      collection.setLocalListPreference( Collection::ListSync, parsePreference( value ) );
+    } else if ( key == "INDEX" ) {
+      collection.setLocalListPreference( Collection::ListIndex, parsePreference( value ) );
+    } else if ( key == "REFERENCED" ) {
+      collection.setReferenced( value == "TRUE" );
     } else {
       Attribute* attr = AttributeFactory::createAttribute( key );
       Q_ASSERT( attr );
@@ -336,6 +361,36 @@ QByteArray ProtocolHelper::tagSetToByteArray( const Tag::List &_objects, const Q
   throw Exception( "Not all tags have a uid" );
 }
 
+QByteArray ProtocolHelper::commandContextToByteArray(const Akonadi::Collection &collection, const Akonadi::Tag &tag,
+                                                     const Item::List &requestedItems, const QByteArray &command)
+{
+    QByteArray r = " ";
+    if (requestedItems.isEmpty()) {
+        r += command + " 1:*";
+    } else {
+        r += ProtocolHelper::entitySetToByteArray(requestedItems, command);
+    }
+
+    if (tag.isValid()) {
+        r += " " AKONADI_PARAM_TAGID " " + QByteArray::number(tag.id()) + " ";
+    }
+
+    if (collection == Collection::root()) {
+        if (requestedItems.isEmpty()) {   // collection content listing
+            throw Exception("Cannot perform item operations on root collection.");
+        }
+    } else {
+        if (collection.isValid()) {
+            r += " " AKONADI_PARAM_COLLECTIONID " " + QByteArray::number(collection.id()) + ' ';
+        } else if (!collection.remoteId().isEmpty()) {
+            r += " " AKONADI_PARAM_COLLECTION " " + ImapParser::quote(collection.remoteId().toUtf8()) + ' ';
+        }
+    }
+
+    return r;
+}
+
+
 QByteArray ProtocolHelper::hierarchicalRidToByteArray( const Collection &col )
 {
   if ( col == Collection::root() )
@@ -392,6 +447,8 @@ QByteArray ProtocolHelper::itemFetchScopeToByteArray( const ItemFetchScope &fetc
     command += " GID";
   if ( fetchScope.fetchTags() )
     command += " TAGS";
+  if ( fetchScope.fetchVirtualReferences() )
+    command += " VIRTREF";
   if ( fetchScope.fetchModificationTime() )
     command += " DATETIME";
   foreach ( const QByteArray &part, fetchScope.payloadParts() )
@@ -491,6 +548,18 @@ void ProtocolHelper::parseItemFetchResult( const QList<QByteArray> &lineTokens,
         }
       }
       item.setTags( tags );
+    } else if ( key == "VIRTREF" ) {
+      ImapSet set;
+      ImapParser::parseSequenceSet( lineTokens[i + 1], set );
+      Collection::List collections;
+      Q_FOREACH ( const ImapInterval &interval, set.intervals() ) {
+        Q_ASSERT( interval.hasDefinedBegin() );
+        Q_ASSERT( interval.hasDefinedEnd() );
+        for ( qint64 i = interval.begin(); i <= interval.end(); i++ ) {
+          collections << Collection(i);
+        }
+      }
+      item.setVirtualReferences(collections);
     } else if ( key == "CACHEDPARTS" ) {
       QSet<QByteArray> partsSet;
       QList<QByteArray> parts;
@@ -574,6 +643,8 @@ void ProtocolHelper::parseTagFetchResult( const QList<QByteArray> &lineTokens, T
       tag.setRemoteId(value);
     } else if (key == "PARENT") {
       tag.setParent(Tag(value.toLongLong()));
+    } else if ( key == "MIMETYPE" ) {
+      tag.setType(value);
     } else {
       Attribute *attr = AttributeFactory::createAttribute(key);
       if (!attr) {
@@ -585,3 +656,100 @@ void ProtocolHelper::parseTagFetchResult( const QList<QByteArray> &lineTokens, T
     }
   }
 }
+
+QString ProtocolHelper::akonadiStoragePath()
+{
+    QString fullRelPath = QLatin1String("akonadi");
+    if (Akonadi::ServerManager::hasInstanceIdentifier()) {
+        fullRelPath += QDir::separator() + QLatin1String("instance") + QDir::separator() + Akonadi::ServerManager::instanceIdentifier();
+    }
+    return XdgBaseDirs::saveDir("data", fullRelPath);
+}
+
+QString ProtocolHelper::absolutePayloadFilePath(const QString &fileName)
+{
+    QFileInfo fi(fileName);
+    if (!fi.isAbsolute()) {
+        return akonadiStoragePath() + QDir::separator() + QLatin1String("file_db_data") + QDir::separator() + fileName;
+    }
+
+    return fileName;
+}
+
+bool ProtocolHelper::streamPayloadToFile(const QByteArray &command, const QByteArray &data, QByteArray &error)
+{
+    const int fnStart = command.indexOf("[FILE ") + 6;
+    if (fnStart == -1) {
+        kDebug() << "Unexpected response";
+        return false;
+    }
+    const int fnEnd = command.indexOf("]", fnStart);
+    const QByteArray fn = command.mid(fnStart, fnEnd - fnStart);
+    const QString fileName = ProtocolHelper::absolutePayloadFilePath(QString::fromLatin1(fn));
+    if (!fileName.startsWith(akonadiStoragePath())) {
+        kWarning() << "Invalid file path" << fileName;
+        error = "Invalid file path";
+        return false;
+    }
+    QFile file(fileName);
+    if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
+        kWarning() << "Failed to open destination payload file" << file.errorString();
+        error = "Failed to store payload into file";
+        return false;
+    }
+    if (file.write(data) != data.size()) {
+        kWarning() << "Failed to write all payload data to file";
+        error = "Failed to store payload into file";
+        return false;
+    }
+    kDebug() << "Wrote" << data.size() << "bytes to " << file.fileName();
+
+    // Make sure stuff is written to disk
+    file.close();
+    return true;
+}
+
+
+QByteArray ProtocolHelper::listPreference(Collection::ListPurpose purpose, Collection::ListPreference preference)
+{
+    QByteArray command;
+    switch(purpose) {
+    case Collection::ListDisplay:
+        command += "DISPLAY ";
+        break;
+    case Collection::ListSync:
+        command += "SYNC ";
+        break;
+    case Collection::ListIndex:
+        command += "INDEX ";
+        break;
+    }
+    switch(preference) {
+    case Collection::ListEnabled:
+        command += "TRUE";
+        break;
+    case Collection::ListDisabled:
+        command += "FALSE";
+        break;
+    case Collection::ListDefault:
+        command += "DEFAULT";
+        break;
+    }
+    return command;
+}
+
+QByteArray ProtocolHelper::enabled(bool state)
+{
+    if (state) {
+      return "ENABLED TRUE";
+    }
+    return "ENABLED FALSE";
+}
+
+QByteArray ProtocolHelper::referenced(bool state)
+{
+    if (state) {
+      return "REFERENCED TRUE";
+    }
+    return "REFERENCED FALSE";
+}
