@@ -33,7 +33,7 @@ using namespace Akonadi;
 class CollectionMoveTest : public QObject
 {
   Q_OBJECT
-  private slots:
+  private Q_SLOTS:
     void initTestCase()
     {
       AkonadiTest::checkTestIsIsolated();
